[![Python application](https://github.com/chrishengler/PyRant/actions/workflows/python-app.yml/badge.svg)](https://github.com/chrishengler/PyRant/actions/workflows/python-app.yml)

### Twaddle ###

Twaddle offers a simple yet powerful way to generate text from templates. Think 
[mad libs](https://en.wikipedia.org/wiki/Mad_Libs) and you're in the general area. 

Twaddle offers various tools and functions to manipulate the output to be as ordered
or as unpredictable as you'd like. See [the documentation](https://chrishengler.github.io/twaddle/)
 or a full overview of Twaddle's capabilities.

Twaddle began life as a partial reimplementation of 
[Rant v3](https://github.com/TheBerkin/rant3), targeting a subset of Rant features
which some friends and I actively used. It should be fully backwards compatible with 
Rant v3 for that targeted subset (see documentation).

Twaddle requires Python version 3.11 or above. 